from distutils.core import setup


setup(  
        name         ='draw-plum',
        version      ='1.1.0',
        py_modules   =['draw-plum'],
        author       ='MarChen',
        author_email ='2210261316@qq.com',
        url          ='http://www.beteceramics.com',
        description  ='an app to draw the beautiful flowers',
      )
